.. include:: <isonum.txt>
.. include:: links.rst

Gradec: Meta-analytic Gradient Decoding
==========================================================

Gradec is a Python package for meta-analytic functional decoding of 
cortical gradient of functional connectivity.

To install Gradec check out our `installation guide`_.

.. _installation guide: installation.html

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   about
   installation
   api
   auto_examples/index
   contributing
   dev_guide
   outputs
   methods
   changelog
   glossary

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. note::
    This document is based on the documentations from the `NiMARE`_ project.